
import os
import json
import pytest
import importlib

# Directory containing plugins
PLUGINS_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'plugins'))

@pytest.mark.parametrize("plugin", ["auth", "admin", "plant", "cli"])
def test_plugin_metadata_and_init(plugin, tmp_path, monkeypatch):
    # Construct plugin path
    plugin_path = os.path.join(PLUGINS_DIR, plugin)
    # Test plugin.json exists and contains required keys
    meta_path = os.path.join(plugin_path, 'plugin.json')
    assert os.path.isfile(meta_path), f"plugin.json missing for {plugin}"
    meta = json.loads(open(meta_path).read())
    for key in ("name", "version", "description"):
        assert key in meta, f"{{key}} missing in {plugin}/plugin.json"
    # Test __init__.py can be imported and has register_cli
    module_name = f"plugins.{plugin}"
    spec = importlib.util.spec_from_file_location(module_name, os.path.join(plugin_path, '__init__.py'))
    module = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(module)
    assert hasattr(module, "register_cli"), f"register_cli missing in {plugin}/__init__.py"
